# Generated by Django 5.0.4 on 2024-05-08 09:26


import wagtail
from django.db import migrations
from wagtail.models import Page

from district.blocks import FullscreenHeaderBlock


def merge_blocks(apps, schema_editor):
    # Get the page model
    DistrictHomePage = apps.get_model("district", "DistrictHomePage")

    # Iterate over all pages that have the StreamField you want to update
    for home_page in DistrictHomePage.objects.all():
        # Get the old content
        old_content = home_page.content.get_prep_value()

        # Create a new list to store the merged blocks
        merged_blocks = []

        # Iterate over the old blocks and extract common fields
        for old_block in old_content:
            desktop_line_1 = ""
            desktop_line_2 = ""

            mobile_line_1 = ""
            mobile_line_2 = ""
            mobile_line_3 = ""

            desktop_image = None
            mobile_image = None

            button_url = None
            button_text = None

            # Titles
            if old_block["type"] in (
                "header_full_size",
                "header_simple",
                "header",
                "hero_banner",
            ):
                split_title = old_block["value"].get("title").split(" ")

                if len(split_title) <= 3:
                    desktop_line_1 = old_block["value"].get("title")
                else:
                    desktop_line_1 = " ".join(split_title[:4])
                    desktop_line_2 = " ".join(split_title[4:])

                if len(split_title) <= 3:
                    mobile_line_1 = old_block["value"].get("title")
                elif len(split_title) <= 6:
                    mobile_line_1 = " ".join(split_title[:3])
                    mobile_line_2 = " ".join(split_title[3:6])
                else:
                    mobile_line_1 = " ".join(split_title[:3])
                    mobile_line_2 = " ".join(split_title[3:6])
                    mobile_line_3 = " ".join(split_title[6:])

            # Images
            if old_block["type"] == "header_full_size":
                desktop_image = mobile_image = old_block["value"].get(
                    "image_background"
                )
            elif old_block["type"] in ("header_simple", "header"):
                desktop_image = mobile_image = old_block["value"].get("image")
            elif old_block["type"] == "hero_banner":
                desktop_image = old_block["value"].get("lg_banner")
                mobile_image = old_block["value"].get("sm_banner")

            # Buttons
            if old_block["type"] == "header_full_size":
                buttons = old_block["value"].get("button_group")

                if len(buttons) != 0:
                    button_url = (
                        buttons[0]["value"]["link"]
                        if buttons[0]["value"]["link"]
                        else (
                            Page.objects.get(id=buttons[0]["value"]["page"]).url
                            if buttons[0]["value"]["page"]
                            else ""
                        )
                    )

                    button_text = buttons[0]["value"]["title"]
            elif old_block["type"] in ("header", "hero_banner"):
                button_url = old_block["value"].get("button_link")
                button_text = old_block["value"].get("button_text")

            # Extract common fields from each block type and create a new FullscreenHeaderBlock
            merged_block_data = FullscreenHeaderBlock().to_python(
                {
                    "desktop_line_1": desktop_line_1,
                    "desktop_line_2": desktop_line_2,
                    "mobile_line_1": mobile_line_1,
                    "mobile_line_2": mobile_line_2,
                    "mobile_line_3": mobile_line_3,
                    "desktop_image": desktop_image,
                    "mobile_image": mobile_image,
                    "desktop_video_url": None,
                    "mobile_video_url": None,
                    "button_url": button_url,
                    "button_text": button_text,
                }
            )

            merged_blocks.append(merged_block_data)

        if len(merged_blocks) == 0:
            merged_blocks = [
                FullscreenHeaderBlock().to_python(
                    {
                        "desktop_line_1": home_page.title,
                        "desktop_line_2": "",
                        "mobile_line_1": home_page.title,
                        "mobile_line_2": "",
                        "mobile_line_3": "",
                        "desktop_image": None,
                        "mobile_image": None,
                        "desktop_video_url": None,
                        "mobile_video_url": None,
                        "button_url": None,
                        "button_text": None,
                    }
                )
            ]

        for block in merged_blocks:
            home_page.content.append(("fullscreen_header_block", block))

        # Save the updated page
        home_page.save()


class Migration(migrations.Migration):
    dependencies = [
        ("district", "0130_rename_subheader_districthomepage_content_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="districthomepage",
            name="content",
            field=wagtail.fields.StreamField(
                [
                    (
                        "header_full_size",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "title",
                                    wagtail.blocks.CharBlock(
                                        label="Titulek", required=True
                                    ),
                                ),
                                (
                                    "image_background",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Obrázek v pozadí", required=True
                                    ),
                                ),
                                (
                                    "image_foreground",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Obrázek v popředí", required=False
                                    ),
                                ),
                                (
                                    "button_group",
                                    wagtail.blocks.ListBlock(
                                        wagtail.blocks.StructBlock(
                                            [
                                                (
                                                    "title",
                                                    wagtail.blocks.CharBlock(
                                                        label="Titulek",
                                                        max_length=128,
                                                        required=True,
                                                    ),
                                                ),
                                                (
                                                    "icon",
                                                    wagtail.blocks.CharBlock(
                                                        help_text="Identifikátor ikonky ze styleguide (https://styleguide.pirati.cz/latest/?p=viewall-atoms-icons), např. ico--key.",
                                                        label="Ikonka",
                                                        max_length=128,
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "size",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("sm", "Malá"),
                                                            ("base", "Střední"),
                                                            ("lg", "Velká"),
                                                        ],
                                                        label="Velikost",
                                                    ),
                                                ),
                                                (
                                                    "color",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("black", "Černá"),
                                                            ("white", "Bílá"),
                                                            ("grey-125", "Světle šedá"),
                                                            ("blue-300", "Modrá"),
                                                            ("cyan-200", "Tyrkysová"),
                                                            ("green-400", "Zelené"),
                                                            ("violet-400", "Vínová"),
                                                            ("red-600", "Červená"),
                                                        ],
                                                        label="Barva",
                                                    ),
                                                ),
                                                (
                                                    "hoveractive",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=True,
                                                        help_text="Pokud je zapnuto, tlačítko mění barvu, když na něj uživatel najede myší.",
                                                        label="Animovat na hover",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "mobile_fullwidth",
                                                    wagtail.blocks.BooleanBlock(
                                                        default=True,
                                                        help_text="Pokud je zapnuto, tlačítko se na mobilních zařízeních roztáhne na plnou šířku.",
                                                        label="Plná šířka na mobilních zařízeních",
                                                        required=False,
                                                    ),
                                                ),
                                                (
                                                    "page",
                                                    wagtail.blocks.PageChooserBlock(
                                                        label="Stránka", required=False
                                                    ),
                                                ),
                                                (
                                                    "link",
                                                    wagtail.blocks.URLBlock(
                                                        label="Odkaz", required=False
                                                    ),
                                                ),
                                                (
                                                    "align",
                                                    wagtail.blocks.ChoiceBlock(
                                                        choices=[
                                                            ("auto", "Automaticky"),
                                                            ("center", "Na střed"),
                                                        ],
                                                        label="Zarovnání",
                                                    ),
                                                ),
                                            ]
                                        ),
                                        label="Tlačítka",
                                    ),
                                ),
                            ]
                        ),
                    ),
                    (
                        "header_simple",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "title",
                                    wagtail.blocks.CharBlock(
                                        label="Titulek", required=False
                                    ),
                                ),
                                (
                                    "subtitle",
                                    wagtail.blocks.CharBlock(
                                        label="Podtitulek", required=False
                                    ),
                                ),
                                ("image", wagtail.images.blocks.ImageChooserBlock()),
                            ]
                        ),
                    ),
                    (
                        "header",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "title",
                                    wagtail.blocks.CharBlock(
                                        help_text="Nap", label="Titulek", required=False
                                    ),
                                ),
                                ("image", wagtail.images.blocks.ImageChooserBlock()),
                                (
                                    "button_text",
                                    wagtail.blocks.CharBlock(
                                        label="Text tlačítka", required=False
                                    ),
                                ),
                                (
                                    "button_link",
                                    wagtail.blocks.URLBlock(
                                        label="Odkaz tlačítka", required=False
                                    ),
                                ),
                            ]
                        ),
                    ),
                    (
                        "hero_banner",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "sm_banner",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Obrázek pro zobrazení menší než 640px",
                                        required=True,
                                    ),
                                ),
                                (
                                    "md_banner",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Obrázek pro zobrazení větší než 768px",
                                        required=True,
                                    ),
                                ),
                                (
                                    "lg_banner",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Obrázek pro zobrazení větší než 1024px",
                                        required=True,
                                    ),
                                ),
                                (
                                    "xl_banner",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Obrázek pro zobrazení větší než 1280px",
                                        required=True,
                                    ),
                                ),
                                (
                                    "xxl_banner",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        label="Obrázek pro zobrazení větší než 1536px",
                                        required=True,
                                    ),
                                ),
                                (
                                    "title",
                                    wagtail.blocks.CharBlock(
                                        label="Titulek bloku", required=False
                                    ),
                                ),
                                (
                                    "subtitle",
                                    wagtail.blocks.CharBlock(
                                        label="Podtitulek", required=False
                                    ),
                                ),
                                (
                                    "button_text",
                                    wagtail.blocks.CharBlock(
                                        label="Text tlačítka", required=False
                                    ),
                                ),
                                (
                                    "button_link",
                                    wagtail.blocks.URLBlock(
                                        label="Odkaz tlačítka", required=False
                                    ),
                                ),
                            ]
                        ),
                    ),
                    (
                        "fullscreen_header_block",
                        wagtail.blocks.StructBlock(
                            [
                                (
                                    "desktop_image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        help_text="Pokud není vybráno video, ukáže se na desktopu.",
                                        label="Obrázek na pozadí (desktop)",
                                    ),
                                ),
                                (
                                    "mobile_image",
                                    wagtail.images.blocks.ImageChooserBlock(
                                        help_text="Pokud není vybráno video, ukáže se na mobilu.",
                                        label="Obrázek na pozadí (mobil)",
                                        required=False,
                                    ),
                                ),
                                (
                                    "desktop_video_url",
                                    wagtail.blocks.URLBlock(
                                        help_text="Pokud je vybráno, ukáže se na desktopech s povoleným autoplayem místo obrázku.",
                                        label="Video (desktop)",
                                        required=False,
                                    ),
                                ),
                                (
                                    "mobile_video_url",
                                    wagtail.blocks.URLBlock(
                                        help_text="Pokud je vybráno, ukáže se na mobilech s povoleným autoplayem místo obrázku.",
                                        label="Video (mobil)",
                                        required=False,
                                    ),
                                ),
                                (
                                    "desktop_line_1",
                                    wagtail.blocks.TextBlock(
                                        label="Desktop první řádek"
                                    ),
                                ),
                                (
                                    "desktop_line_2",
                                    wagtail.blocks.TextBlock(
                                        label="Desktop druhý řádek"
                                    ),
                                ),
                                (
                                    "mobile_line_1",
                                    wagtail.blocks.TextBlock(
                                        label="První mobilní řádek"
                                    ),
                                ),
                                (
                                    "mobile_line_2",
                                    wagtail.blocks.TextBlock(
                                        label="Druhý mobilní řádek"
                                    ),
                                ),
                                (
                                    "mobile_line_3",
                                    wagtail.blocks.TextBlock(
                                        label="Třetí mobilní řádek"
                                    ),
                                ),
                                (
                                    "button_url",
                                    wagtail.blocks.URLBlock(
                                        help_text="Bez odkazu tlačítko nebude viditelné.",
                                        label="Odkaz tlačítka",
                                        required=False,
                                    ),
                                ),
                                (
                                    "button_text",
                                    wagtail.blocks.CharBlock(
                                        label="Text tlačítka", required=False
                                    ),
                                ),
                            ]
                        ),
                    ),
                ],
                blank=True,
                verbose_name="Blok pod headerem",
            ),
        ),
        migrations.RunPython(merge_blocks),
    ]
