from django.db import models

from wagtail.models import Page
from wagtail.fields import RichTextField, StreamField
from shared.const import RICH_TEXT_DEFAULT_FEATURES
from .blocks import CommonWishBlock, TourDateBlock
from shared.models import (
    ExtendedMetadataHomePageMixin,
)
from wagtailmetadata.models import MetadataPageMixin
from wagtail.admin.panels import FieldPanel


class MakeAWishRoot(
    Page, ExtendedMetadataHomePageMixin, MetadataPageMixin
):
    main_text = RichTextField(verbose_name="Hlavní text", features=RICH_TEXT_DEFAULT_FEATURES)

    new_wish_image = models.ForeignKey(
        "wagtailimages.Image",
        on_delete=models.PROTECT,
        blank=True,
        null=True,
        verbose_name="Obrázek k novému prání",
    )

    video_url = models.URLField(
        verbose_name="URL Videa vpravo",
        help_text="Automaticky se spustí bez zvuku"
    )

    common_wishes = StreamField(
        [
            ("wish", CommonWishBlock())
        ],
        verbose_name="Nejčastější přání"
    )

    tour_dates = StreamField(
        [
            ("tour_date", TourDateBlock())
        ],
        verbose_name="Tour termíny"
    )

    content_panels = Page.content_panels + [
        FieldPanel("main_text"),
        FieldPanel("new_wish_image"),
        FieldPanel("video_url"),
        FieldPanel("common_wishes"),
        FieldPanel("tour_dates"),
    ]

    class Meta:
        verbose_name = "Máte přání"